# dyff

![Version: 0.0.0](https://img.shields.io/badge/Version-0.0.0-informational?style=flat-square) ![Type: application](https://img.shields.io/badge/Type-application-informational?style=flat-square) ![AppVersion: 1.16.0](https://img.shields.io/badge/AppVersion-1.16.0-informational?style=flat-square)

A Helm chart for Kubernetes

## Values

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| api.affinity | object | `{}` |  |
| api.autoscaling.enabled | bool | `false` |  |
| api.autoscaling.maxReplicas | int | `100` |  |
| api.autoscaling.minReplicas | int | `1` |  |
| api.autoscaling.targetCPUUtilizationPercentage | int | `80` |  |
| api.containerSecurityContext | object | `{}` |  |
| api.extraEnvVarsConfigMap | object | `{"DYFF_API__AUTH__MONGODB__DATABASE":"accounts","DYFF_API__QUERY__MONGODB__DATABASE":"workflows","DYFF_KAFKA__CONFIG__BOOTSTRAP_SERVERS":"kafka.kafka.svc.cluster.local","DYFF_KAFKA__TOPICS__WORKFLOWS_EVENTS":"dyff.workflows.events","DYFF_KAFKA__TOPICS__WORKFLOWS_STATE":"dyff.workflows.state","DYFF_WORKFLOWS_SINK__MONGODB__DATABASE":"workflows"}` | Set environment variables in the `dyff-api` Deployment via ConfigMap. |
| api.extraEnvVarsSecret | object | `{}` | Set environment variables in the `dyff-api` Deployment via Secret. |
| api.image.pullPolicy | string | `"IfNotPresent"` |  |
| api.image.repository | string | `"registry.gitlab.com/ul-dsri/dyff/dyff/api"` |  |
| api.image.tag | string | `""` |  |
| api.ingress.annotations | object | `{}` |  |
| api.ingress.className | string | `""` |  |
| api.ingress.enabled | bool | `false` |  |
| api.ingress.hosts[0].host | string | `"api.dyff.local"` |  |
| api.ingress.hosts[0].paths[0].path | string | `"/"` |  |
| api.ingress.hosts[0].paths[0].pathType | string | `"ImplementationSpecific"` |  |
| api.ingress.tls | list | `[]` |  |
| api.nodeSelector | object | `{}` |  |
| api.podAnnotations | object | `{}` |  |
| api.podLabels | object | `{}` |  |
| api.podSecurityContext | object | `{}` |  |
| api.replicaCount | int | `1` |  |
| api.resources | object | `{}` |  |
| api.service.port | int | `8080` |  |
| api.service.type | string | `"ClusterIP"` |  |
| api.serviceAccount.annotations | object | `{}` |  |
| api.serviceAccount.automount | bool | `true` |  |
| api.serviceAccount.create | bool | `true` |  |
| api.serviceAccount.name | string | `""` |  |
| api.tolerations | list | `[]` |  |
| api.volumeMounts | list | `[]` |  |
| api.volumes | list | `[]` |  |
| fullnameOverride | string | `""` |  |
| imagePullSecrets | list | `[]` |  |
| nameOverride | string | `""` |  |
| orchestrator.affinity | object | `{}` |  |
| orchestrator.containerSecurityContext | object | `{}` |  |
| orchestrator.db.volumeSpec.accessModes[0] | string | `"ReadWriteOnce"` |  |
| orchestrator.db.volumeSpec.resources.requests.storage | string | `"10Gi"` |  |
| orchestrator.extraEnvVarsConfigMap | object | `{"DYFF_KAFKA__CONFIG__BOOTSTRAP_SERVERS":"kafka.kafka.svc.cluster.local","DYFF_KAFKA__TOPICS__WORKFLOWS_EVENTS":"dyff.workflows.events","DYFF_KAFKA__TOPICS__WORKFLOWS_STATE":"dyff.workflows.state"}` | Set environment variables in the `dyff-orchestrator` StatefulSet via ConfigMap. |
| orchestrator.extraEnvVarsSecret | object | `{}` | Set environment variables in the `dyff-orchestrator` StatefulSet via Secret. |
| orchestrator.image.pullPolicy | string | `"IfNotPresent"` |  |
| orchestrator.image.repository | string | `"registry.gitlab.com/ul-dsri/dyff/dyff/orchestrator"` |  |
| orchestrator.image.tag | string | `""` |  |
| orchestrator.ingress.annotations | object | `{}` |  |
| orchestrator.ingress.className | string | `""` |  |
| orchestrator.ingress.enabled | bool | `false` |  |
| orchestrator.ingress.hosts[0].host | string | `"orchestrator.dyff.local"` |  |
| orchestrator.ingress.hosts[0].paths[0].path | string | `"/"` |  |
| orchestrator.ingress.hosts[0].paths[0].pathType | string | `"ImplementationSpecific"` |  |
| orchestrator.ingress.tls | list | `[]` |  |
| orchestrator.nodeSelector | object | `{}` |  |
| orchestrator.podAnnotations | object | `{}` |  |
| orchestrator.podLabels | object | `{}` |  |
| orchestrator.podSecurityContext | object | `{}` |  |
| orchestrator.replicaCount | int | `1` |  |
| orchestrator.resources | object | `{}` |  |
| orchestrator.serviceAccount.annotations | object | `{}` |  |
| orchestrator.serviceAccount.automount | bool | `true` |  |
| orchestrator.serviceAccount.create | bool | `true` |  |
| orchestrator.serviceAccount.name | string | `""` |  |
| orchestrator.tolerations | list | `[]` |  |
| orchestrator.volumeMounts | list | `[]` |  |
| orchestrator.volumes | list | `[]` |  |

----------------------------------------------
Autogenerated from chart metadata using [helm-docs v1.12.0](https://github.com/norwoodj/helm-docs/releases/v1.12.0)
